package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.Issuer;

/**
 * 发行方Mapper接口
 *
 * @author ruoyi
 * @date 2023-02-14
 */
public interface IssuerMapper
{
    /**
     * 查询发行方
     *
     * @param id 发行方主键
     * @return 发行方
     */
    public Issuer selectIssuerById(Long id);

    /**
     * 通过发行方的名字查询ID
     *
     * @param issuerName 发行方的名字
     * @return ID
     */
    public Long selectIssuerByIdForIssuerName(String issuerName);
    /**
     * 查询发行方列表
     *
     * @param issuer 发行方
     * @return 发行方集合
     */
    public List<Issuer> selectIssuerList(Issuer issuer);

    /**
     * 新增发行方
     *
     * @param issuer 发行方
     * @return 结果
     */
    public int insertIssuer(Issuer issuer);

    /**
     * 修改发行方
     *
     * @param issuer 发行方
     * @return 结果
     */
    public int updateIssuer(Issuer issuer);

    /**
     * 删除发行方
     *
     * @param id 发行方主键
     * @return 结果
     */
    public int deleteIssuerById(Long id);

    /**
     * 批量删除发行方
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteIssuerByIds(Long[] ids);

    List<Issuer> selectByIssuerName(String issuerName);
}
